@@ -6,6 +6,7 @@ which has attributes:
 
   - time: read-only scalar float
   - gmtime: read-only sequence (spectrum) of integers
+  - noon:  read-only enumerated type
 
 commands:
 
@@ -14,7 +15,13 @@ commands:
 """
 
 import time
-from PyTango.server import Device, attribute, command
+from enum import IntEnum
+from tango.server import Device, attribute, command
+
+
+class Noon(IntEnum):
+    AM = 0  # DevEnum's must start at 0
+    PM = 1  # and increment by 1
 
 
 class Clock(Device):
@@ -28,6 +35,11 @@ class Clock(Device):
     def read_gmtime(self):
         return time.gmtime()
 
+    @attribute(dtype=Noon)
+    def noon(self):
+        time_struct = time.gmtime(time.time())
+        return Noon.AM if time_struct.tm_hour < 12 else Noon.PM
+
     @command(dtype_in=float, dtype_out=str)
     def ctime(self, seconds):
         """
