@@ -20,17 +20,17 @@ import sys
 import PyTango
 
 if len(sys.argv) != 2:
-    print "must provide one and only one clock device name"
+    print("must provide one and only one clock device name")
     sys.exit(1)
 
 clock = PyTango.DeviceProxy(sys.argv[1])
 t = clock.time
 gmt = clock.gmtime
+noon = clock.noon
 print(t)
 print(gmt)
+print(noon, noon.name, noon.value)
+if noon == noon.AM:
+    print('Good morning!')
 print(clock.ctime(t))
 print(clock.mktime(gmt))
-
-
-
-
