@@ -13,7 +13,7 @@
 This is an internal PyTango module.
 """
 
-__all__ = ["Release"]
+__all__ = ("Release",)
 
 __docformat__ = "restructuredtext"
 
@@ -44,8 +44,8 @@ class Release:
         - keywords: (seq<str>) list of keywords
         - license: (str) the license
     """
-    name = 'PyTango'
-    version_info = (9, 2, 2)
+    name = 'pytango'
+    version_info = (9, 2, 4)
     version = '.'.join(map(str, version_info[:3]))
     release = ''.join(map(str, version_info[3:]))
     separator = '.' if 'dev' in release or 'post' in release else ''
