@@ -1,5 +1,7 @@
 """Test utilities"""
 
+import enum
+
 # Local imports
 from . import DevState, GreenMode
 from .server import Device
@@ -16,7 +18,7 @@ try:
 except ImportError:
     numpy = None
 
-__all__ = ['DeviceTestContext', 'SimpleDevice']
+__all__ = ('DeviceTestContext', 'SimpleDevice')
 
 
 # Test devices
@@ -26,6 +28,32 @@ class SimpleDevice(Device):
         self.set_state(DevState.ON)
 
 
+# Test enums
+
+class GoodEnum(enum.IntEnum):
+    START = 0
+    MIDDLE = 1
+    END = 2
+
+
+class BadEnumNonZero(enum.IntEnum):
+    START = 1
+    MIDDLE = 2
+    END = 3
+
+
+class BadEnumSkipValues(enum.IntEnum):
+    START = 0
+    MIDDLE = 2
+    END = 4
+
+
+class BadEnumDuplicates(enum.IntEnum):
+    START = 0
+    MIDDLE = 1
+    END = 1
+
+
 # Helpers
 
 TYPED_VALUES = {
