@@ -3,11 +3,15 @@
 import sys
 import textwrap
 import pytest
+import enum
 
 from tango import DevState, AttrWriteType, GreenMode, DevFailed
 from tango.server import Device
 from tango.server import command, attribute, device_property
-from tango.test_utils import DeviceTestContext, assert_close
+from tango.test_utils import DeviceTestContext, assert_close, \
+    GoodEnum, BadEnumNonZero, BadEnumSkipValues, BadEnumDuplicates
+from tango.utils import get_enum_labels, EnumTypeError
+
 
 # Asyncio imports
 try:
@@ -15,10 +19,6 @@ try:
 except ImportError:
     import trollius as asyncio  # noqa: F401
 
-# Pytest fixtures
-from tango.test_utils import state, typed_values, server_green_mode
-state, typed_values, server_green_mode
-
 # Constants
 PY3 = sys.version_info >= (3,)
 YIELD_FROM = "yield from" if PY3 else "yield asyncio.From"
@@ -144,6 +144,67 @@ def test_read_write_attribute(typed_values, server_green_mode):
             assert_close(proxy.attr, value)
 
 
+def test_read_write_attribute_enum(server_green_mode):
+    values = (member.value for member in GoodEnum)
+    enum_labels = get_enum_labels(GoodEnum)
+
+    class TestDevice(Device):
+        green_mode = server_green_mode
+
+        def __init__(self, *args, **kwargs):
+            super(TestDevice, self).__init__(*args, **kwargs)
+            self.attr_from_enum_value = 0
+            self.attr_from_labels_value = 0
+
+        @attribute(dtype=GoodEnum, access=AttrWriteType.READ_WRITE)
+        def attr_from_enum(self):
+            return self.attr_from_enum_value
+
+        @attr_from_enum.write
+        def attr_from_enum(self, value):
+            self.attr_from_enum_value = value
+
+        @attribute(dtype='DevEnum', enum_labels=enum_labels,
+                   access=AttrWriteType.READ_WRITE)
+        def attr_from_labels(self):
+            return self.attr_from_labels_value
+
+        @attr_from_labels.write
+        def attr_from_labels(self, value):
+            self.attr_from_labels_value = value
+
+    with DeviceTestContext(TestDevice) as proxy:
+        for value, label in zip(values, enum_labels):
+            proxy.attr_from_enum = value
+            read_attr = proxy.attr_from_enum
+            assert read_attr == value
+            assert isinstance(read_attr, enum.IntEnum)
+            assert read_attr.value == value
+            assert read_attr.name == label
+            proxy.attr_from_labels = value
+            read_attr = proxy.attr_from_labels
+            assert read_attr == value
+            assert isinstance(read_attr, enum.IntEnum)
+            assert read_attr.value == value
+            assert read_attr.name == label
+
+    with pytest.raises(TypeError) as context:
+        class BadTestDevice(Device):
+            green_mode = server_green_mode
+
+            def __init__(self, *args, **kwargs):
+                super(BadTestDevice, self).__init__(*args, **kwargs)
+                self.attr_value = 0
+
+            # enum_labels may not be specified if dtype is an enum.Enum
+            @attribute(dtype=GoodEnum, enum_labels=enum_labels)
+            def bad_attr(self):
+                return self.attr_value
+
+        BadTestDevice()  # dummy instance for Codacy
+    assert 'enum_labels' in str(context.value)
+
+
 # Test properties
 
 def test_device_property_no_default(typed_values, server_green_mode):
@@ -307,3 +368,27 @@ def test_mandatory_device_property(typed_values, server_green_mode):
         with DeviceTestContext(TestDevice, process=True) as proxy:
             pass
     assert 'Device property prop is mandatory' in str(context.value)
+
+
+# fixtures
+
+@pytest.fixture(params=[GoodEnum])
+def good_enum(request):
+    return request.param
+
+
+@pytest.fixture(params=[BadEnumNonZero, BadEnumSkipValues, BadEnumDuplicates])
+def bad_enum(request):
+    return request.param
+
+
+# test utilities for servers
+
+def test_get_enum_labels_success(good_enum):
+    expected_labels = ['START', 'MIDDLE', 'END']
+    assert get_enum_labels(good_enum) == expected_labels
+
+
+def test_get_enum_labels_fail(bad_enum):
+    with pytest.raises(EnumTypeError):
+        get_enum_labels(bad_enum)
